const env = "__ENV__"

import wepy from "wepy";
import { md5 } from "md5";
import client from "client";
import cacheData from "cacheData";

export const config = {
    'api': (() => {
        let envMap = {
            'dev': 'https://test-wxapi-glance.duowan.com',//本地&测试
            'preview': 'https://wxapi-glance.duowan.com',		//预发布
            'production': 'https://wxapi-glance.duowan.com',	//线上
        }

        return envMap[env]
    })(),
    'apiPlus': (() => {
        let envMap = {
            'dev': 'https://test-glplus.duowan.com',	//本地&测试
            'preview': 'https://glplus.duowan.com',		//预发布
            'production': 'https://glplus.duowan.com',	//线上
        }
        return envMap[env]
    })(),
    'SHOP_ID': 17,
    'APP_ID': 1002
}

export const lib = {
    //转换格式时间戳0000-00-00
    formatDate(timestamp) {
        if (!timestamp) return "未知";

        let date = new Date(timestamp);
        return [date.getYear() + 1900, date.getMonth() + 1, date.getDate()]
            .map(item => {
                return item >= 10 ? item : "0" + item;
            })
            .join("-");
    },
    encodePwd(random, pwd) {
        var k1 = md5.sha1(random);
        var k2 = md5.sha1(k1);

        var v = md5.xor(md5.xor(pwd, k2), k1);
        return md5.base64encode(v);
    },
    //任务上报
    reportTask(task_id) { //glancePlayMinute:看视频;share:分享;daySign:每日签到
        let loginData = wx.getStorageSync('loginData')

        if (!task_id && !loginData) return

        let timeStamp = (new Date()).getTime()
        let data = {
            shop_id: config.SHOP_ID,
            task_id: task_id,
            target_id: loginData.uid,
            time: timeStamp
        }

        let paramData = `shop_id=${config.SHOP_ID}&task_id=${task_id}&target_id=${loginData.uid}&time=${timeStamp}`
        data["sign"] = this.encodePwd(loginData.token, md5.sha1(paramData));

        return new Promise((resolve, reject) => {
            wepy
                .request({
                    url: `${config.apiPlus}/task/report`,
                    data: data
                }).then(({ data }) => {
                    if (data.code == 0) {
                        resolve(true)
                    } else {
                        if (task_id == "daySign") wx.showToast({ title: data.msg || '' })

                        resolve(false)
                    }
                })
        })
    },
    // 分享
    shareInfo(yyuid) {
        let loginData = wx.getStorageSync('loginData')
        if (!loginData) return false
        let otoken = loginData.token
        let ouid = loginData.uid
        let openid = loginData.openId;
        return new Promise((resolve, reject) => {
            wepy.request({
                url: `${config.apiPlus}/user/shareInfo`,
                data: {
                    ouid,
                    otoken,
                    yyuid,
                    openid
                }
            }).then(({ data }) => {
                if (data.code == 0) {
                    resolve(data.data)
                } else {
                    resolve(false)
                }
            })
        })
    },

    getShareImage(){
        let random = Math.floor(Math.random()*8)
            random = random>7 ? 7 : random
        let image = `https://pub.dwstatic.com/act/glancewx/share/cover${random}.jpg`
        
        return image
    },
    //处理皮肤数据
    handleSkinData(skinData){
        const rarityMap = {
                common: 0,
                uncommon: 1,
                rare: 2,
                epic: 3,
                legendary: 4
            }

        for (let skin of skinData) {
            if (skin.type === 'back bling') {
                skin.type = 'backbling'
            }
            if (skin.type === 'skydiving trail') {
                skin.type = 'trail'
            }
            skin.rarity_num = rarityMap[skin.rarity]

            //获取类型
            skin.obtainedType = skin.obtained_origin;
            if(skin.obtained_origin.match(/fl?ip/)) skin.obtainedType = "flip";
            if(skin.obtainedType!=="vbucks" && skin.obtainedType!=="vbucks" && skin.obtainedType!=="vbucks") {
                skin.obtainedType ="none"
            }

            if (skin.obtainedType === 'vbucks') {
                // 如果皮肤可以用金币获得，就设置一个price字段存放其价格
                if (skin.obtained_origin.match(/\d,?\d{2,}/)) {
                    skin.price = skin.obtained_origin.match(/\d,?\d{2,}/)[0].replace(',', '')
                }
            } else if (skin.obtainedType === 'vip' || skin.obtainedType === 'flip') {
                // 如果皮肤是勋章获得，就保存其赛季，勋章等级和金银牌等级
                if (skin.obtained_origin.match(/s(\d+)/)) {
                    skin.season = skin.obtained_origin.match(/s(\d+)/)[1]
                }
                if (skin.obtained_origin.match(/-(\d+)-/)) {
                    skin.medalLevel = skin.obtained_origin.match(/-(\d+)-/)[1]
                }
                if (skin.obtainedType === 'vip') {
                    skin.obtainedLevel = 1
                } else {
                    skin.obtainedLevel = 0
                }

                //战阶信息
                if (!skin.season || !skin.medalLevel) {  
                    skin.vipText = ""
                } else {
                    skin.vipText = !skin.season || !skin.medalLevel ? skin.obtained : `S${skin.season}-${skin.medalLevel}战阶`
                }
            } else {
                skin.price = 'none'
            }
        }

        return skinData;

    }
}



